==> gatsby-source-datocms-2.5.17.tgz: package/hooks/sourceNodes/createTypes/fieldTypes/DatoCmsFileField.js <==
"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var buildAssetFields = require('../utils/buildAssetFields');

module.exports = function (_ref) {
  var actions = _ref.actions,
      schema = _ref.schema;
  actions.createTypes([schema.buildObjectType({
    name: 'DatoCmsFileField',
    extensions: {
      infer: false
    },
    fields: _objectSpread({}, buildAssetFields(), {
      alt: 'String',
      title: 'String',
      customData: 'JSON',
      focalPoint: 'DatoCmsFocalPoint'
    })
  }), schema.buildObjectType({
    name: 'DatoCmsFocalPoint',
    extensions: {
      infer: false
    },
    fields: {
      x: 'Float!',
      y: 'Float!'
    }
  })]);
};

==> gatsby-source-datocms-2.6.10.tgz: package/hooks/sourceNodes/createTypes/fieldTypes/DatoCmsFileField.js <==
"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var buildAssetFields = require('../utils/buildAssetFields');

module.exports = function (_ref) {
  var actions = _ref.actions,
      schema = _ref.schema,
      cacheDir = _ref.cacheDir;
  actions.createTypes([schema.buildObjectType({
    name: 'DatoCmsFileField',
    extensions: {
      infer: false
    },
    fields: _objectSpread({}, buildAssetFields({
      cacheDir: cacheDir
    }), {
      alt: 'String',
      title: 'String',
      customData: 'JSON',
      focalPoint: 'DatoCmsFocalPoint'
    })
  }), schema.buildObjectType({
    name: 'DatoCmsFocalPoint',
    extensions: {
      infer: false
    },
    fields: {
      x: 'Float!',
      y: 'Float!'
    }
  })]);
};
